<<<<<<< HEAD
# BabyTalk

BabyTalk is a Python library designed to simplify Python programming using natural language commands. It is intended to make Python more accessible for young learners by allowing them to write code as if they are writing sentences in English.

## Installation

To install BabyTalk, use pip:

```bash
pip install babytalk
=======
# BabyTalk

BabyTalk is a Python library designed to simplify Python programming using natural language commands. It is intended to make Python more accessible for young learners by allowing them to write code as if they are writing sentences in English.

## Installation

To install BabyTalk, use pip:

```bash
pip install babytalk
>>>>>>> 2a3303a7dd4c9f0fd4d140cf35bb62987d9665b4
